@@ -19,7 +19,7 @@ class LightSpeedCog(commands.Cog):
     @commands.has_role("Shiny")
     async def ls_price_lookup_command(self, context: discord.Interaction, search: str):
         """Look up price in Lightspeed"""
-        await context.response.defer()
+        # await context.response.defer()
         generate_ls_access()
         items = Item.get_item_by_desciption(search)
         if items is None:
